import{K as n,E as p,L as a}from"./repository.039c7fed.js";import{d as s,b as m,c,u as e}from"./outputWidgets.fe662b4f.js";import{l as d}from"./index.9315c38c.js";import"./asyncComputed.60882aa5.js";import"./api.7f947c31.js";import"./index.cf4c23b9.js";import"./icons.06e79e54.js";import"./index.96fe91d4.js";import"./ant-design.f876da58.js";import"./index.fb6346ff.js";import"./Modal.c3452f91.js";import"./Text.79714a42.js";import"./Base.752e5f84.js";import"./Typography.a9c97257.js";import"./index.6c541f9d.js";import"./index.dde80ded.js";import"./Paragraph.4acd5c9c.js";import"./index.631cf821.js";import"./Link.dcb8bcbe.js";import"./Title.694e574f.js";import"./index.074bcfaa.js";import"./CollapsePanel.b706068f.js";import"./Form.240adf1b.js";import"./hasIn.36cbd9d8.js";import"./Timeline.85d7943e.js";import"./index.039fa7cf.js";import"./index.1608f48c.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.b9a5df9d.js";import"./workspaces.6064f9d9.js";import"./runnerData.3ec47f83.js";import"./url.e299df37.js";import"./record.b07c9a4f.js";import"./pubsub.d5a444ac.js";import"./scripts.af61bac8.js";import"./envVars.1103c47b.js";import"./ExpandOutlined.bc4a48ee.js";import"./Card.e18b23d2.js";import"./TabPane.37e2c766.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="94a34954-9796-42ba-9625-719867d8f40e",t._sentryDebugIdIdentifier="sentry-dbid-94a34954-9796-42ba-9625-719867d8f40e")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=s({__name:"WorkflowKanban",setup(t){const o=new p,r=new f,i=new a("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.d34f92d9.js.map
