import{v as t,b as s,ev as a}from"./outputWidgets.fe662b4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fdfaa994-6817-45c5-b5f8-1f4a7e18498f",e._sentryDebugIdIdentifier="sentry-dbid-fdfaa994-6817-45c5-b5f8-1f4a7e18498f")}catch{}})();const f={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const c=t(f,[["render",r]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.51014175.js.map
