import{g as m}from"./api.ff49b5fe.js";import{P as c}from"./Passwordless.e7517e29.js";import{a as p}from"./asyncComputed.60882aa5.js";import{W as u}from"./WidgetsFrame.16ceb076.js";import{d as f,eA as l,eB as _,b as d,ev as y,e as b,u as a,c as g,w as h,ex as w,f as v,v as k}from"./outputWidgets.fe662b4f.js";import"./runnerData.3ec47f83.js";import"./url.e299df37.js";import"./index.9315c38c.js";import"./pubsub.d5a444ac.js";import"./icons.06e79e54.js";import"./CircularLoading.43895b43.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3737bbb6-0181-4490-bf60-65a105aaa4d3",e._sentryDebugIdIdentifier="sentry-dbid-3737bbb6-0181-4490-bf60-65a105aaa4d3")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=p(m),i=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[b("div",x,[a(o)?(d(),g(u,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(c,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.dcfbd444.js.map
