import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.3f3ae67c.js";import{K as f,P as d,L as b}from"./repository.039c7fed.js";import{d as l,b as u,ev as c,f as p,u as r}from"./outputWidgets.fe662b4f.js";import{u as g}from"./index.9315c38c.js";import{a as y}from"./asyncComputed.60882aa5.js";import{g as _}from"./api.ff49b5fe.js";import"./Text.79714a42.js";import"./Base.752e5f84.js";import"./Typography.a9c97257.js";import"./index.631cf821.js";import"./Link.dcb8bcbe.js";import"./Paragraph.4acd5c9c.js";import"./Title.694e574f.js";import"./index.0ba8ec00.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.7f947c31.js";import"./index.cf4c23b9.js";import"./icons.06e79e54.js";import"./index.96fe91d4.js";import"./ant-design.f876da58.js";import"./index.fb6346ff.js";import"./Modal.c3452f91.js";import"./index.6c541f9d.js";import"./index.dde80ded.js";import"./index.074bcfaa.js";import"./CollapsePanel.b706068f.js";import"./Form.240adf1b.js";import"./hasIn.36cbd9d8.js";import"./Timeline.85d7943e.js";import"./index.039fa7cf.js";import"./index.1608f48c.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.b9a5df9d.js";import"./workspaces.6064f9d9.js";import"./runnerData.3ec47f83.js";import"./url.e299df37.js";import"./record.b07c9a4f.js";import"./pubsub.d5a444ac.js";import"./scripts.af61bac8.js";import"./envVars.1103c47b.js";import"./ExpandOutlined.bc4a48ee.js";import"./Card.e18b23d2.js";import"./TabPane.37e2c766.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="bcfee76e-4b6d-4a7e-bf02-56f9a44e1580",o._sentryDebugIdIdentifier="sentry-dbid-bcfee76e-4b6d-4a7e-bf02-56f9a44e1580")}catch{}})();const fo=l({__name:"Kanban",setup(o){const t=new d(g),a=new b("kanban"),{result:e}=y(_);return(k,w)=>{var i,n,m;return u(),c("div",null,[p(s,{"brand-name":((i=r(e))==null?void 0:i.brandName)||((n=r(e))==null?void 0:n.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(f,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.23055753.js.map
