import"./outputWidgets.fe662b4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c5614be3-db27-432a-93a2-ea78801325a7",e._sentryDebugIdIdentifier="sentry-dbid-c5614be3-db27-432a-93a2-ea78801325a7")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.e299df37.js.map
