import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.3f3ae67c.js";import{g as p}from"./api.ff49b5fe.js";import{a as _}from"./asyncComputed.60882aa5.js";import{W as y}from"./WidgetsFrame.16ceb076.js";import{d as g,eB as b,b as n,ev as h,e as s,u as t,c as d,w as v,ex as l,eD as u,v as w}from"./outputWidgets.fe662b4f.js";import"./index.9315c38c.js";import"./pubsub.d5a444ac.js";import"./Text.79714a42.js";import"./Base.752e5f84.js";import"./Typography.a9c97257.js";import"./index.631cf821.js";import"./Link.dcb8bcbe.js";import"./Paragraph.4acd5c9c.js";import"./Title.694e574f.js";import"./index.0ba8ec00.js";import"./ArrowRightOutlined.08fa31dd.js";import"./runnerData.3ec47f83.js";import"./url.e299df37.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="add79088-392b-4cef-ad5a-8143a3fb9254",o._sentryDebugIdIdentifier="sentry-dbid-add79088-392b-4cef-ad5a-8143a3fb9254")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=g({__name:"Error",setup(o){const r=b(),{result:e}=_(p),i=()=>{const{status:a}=r.params;switch(a){case"404":return{status:a,message:"Page not found."};case"403":return{status:a,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(a,B)=>(n(),h("div",null,[s("div",k,[t(e)?(n(),d(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var m,c;return[t(e)?(n(),d(f,{key:0,"brand-name":((m=t(e))==null?void 0:m.brandName)||((c=t(e))==null?void 0:c.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),s("div",I,[s("h1",null,u(i().status),1),s("p",null,u(i().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.7972a313.js.map
