import{cz as n}from"./outputWidgets.fe662b4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="48a6b0b4-88c7-4866-9613-1f48e8358373",e._sentryDebugIdIdentifier="sentry-dbid-48a6b0b4-88c7-4866-9613-1f48e8358373")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.1d786c53.js.map
