import{eN as t,eO as r}from"./outputWidgets.fe662b4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="0b89d502-6b89-4b32-9836-b3fd2b8f6a7c",e._sentryDebugIdIdentifier="sentry-dbid-0b89d502-6b89-4b32-9836-b3fd2b8f6a7c")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.dde80ded.js.map
