import{S as p}from"./Sidebar.1aee6371.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.550aba13.js";import{L as d,M as l,N as u}from"./icons.06e79e54.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.fe662b4f.js";import{a as w}from"./asyncComputed.60882aa5.js";import"./router.359674ae.js";import"./index.dc77b07b.js";import{O as z}from"./organization.11aff731.js";import{B as h}from"./BaseLayout.4608b526.js";import"./index.6c541f9d.js";import"./logo.084e5d7c.js";import"./Text.79714a42.js";import"./Base.752e5f84.js";import"./Typography.a9c97257.js";import"./index.0ba8ec00.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.240adf1b.js";import"./hasIn.36cbd9d8.js";import"./index.cf4c23b9.js";import"./record.b07c9a4f.js";import"./pubsub.d5a444ac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f6e10898-e1bb-4ca5-90d2-96e3e449441a",e._sentryDebugIdIdentifier="sentry-dbid-f6e10898-e1bb-4ca5-90d2-96e3e449441a")}catch{}})();const K=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.db516743.js.map
