import{d,eB as b,H as m,a as f,b as g,c as v,w as s,f as i}from"./outputWidgets.fe662b4f.js";import{B as _}from"./BaseLayout.4608b526.js";import{a as h}from"./asyncComputed.60882aa5.js";import"./router.359674ae.js";import"./index.dc77b07b.js";import{P as y}from"./project.c86572f1.js";import{O as w}from"./organization.11aff731.js";import{_ as z}from"./Navbar.vue_vue_type_script_setup_true_lang.550aba13.js";import{S as I}from"./Sidebar.1aee6371.js";import{e as j,Q as C,R as O,S as k,T as B,v as S,G as L,U as P,V as x,M as D}from"./icons.06e79e54.js";import"./Form.240adf1b.js";import"./hasIn.36cbd9d8.js";import"./index.cf4c23b9.js";import"./record.b07c9a4f.js";import"./pubsub.d5a444ac.js";import"./logo.084e5d7c.js";import"./Text.79714a42.js";import"./Base.752e5f84.js";import"./Typography.a9c97257.js";import"./index.0ba8ec00.js";import"./ArrowRightOutlined.08fa31dd.js";import"./index.6c541f9d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="2b68caad-86bf-495a-80b8-b19d8959a7fe",o._sentryDebugIdIdentifier="sentry-dbid-2b68caad-86bf-495a-80b8-b19d8959a7fe")}catch{}})();const oa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:e}=h(()=>y.get(c).then(async a=>{const t=await w.get(a.organizationId);return{project:a,organization:t}})),l=m(()=>{var a,t,n,p;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=e.value)==null?void 0:p.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),u=m(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Live",path:"live",icon:j},{name:"Builds",path:"builds",icon:C},{name:"Connectors",path:"connectors",icon:O,unavailable:!e.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:B},{name:"Env Vars",path:"env-vars",icon:S},{name:"Files",path:"files",icon:L},{name:"Logs",icon:P,path:"logs"},{name:"Settings",icon:x,path:"settings"},{name:"Users",icon:D,path:"users"}]}]:[]});return(a,t)=>{const n=f("router-view");return g(),v(_,null,{content:s(()=>[i(n)]),navbar:s(()=>[i(z,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:s(()=>[i(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.a3013859.js.map
