import{B as s}from"./Base.752e5f84.js";import{A as a}from"./Link.dcb8bcbe.js";import{A as o}from"./Paragraph.4acd5c9c.js";import{A as r}from"./Text.79714a42.js";import{A as i}from"./Title.694e574f.js";import{T as e}from"./Typography.a9c97257.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="6a685c4b-0bf5-49e7-bc46-5f7faec4d02a",n._sentryDebugIdIdentifier="sentry-dbid-6a685c4b-0bf5-49e7-bc46-5f7faec4d02a")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.631cf821.js.map
